@@ -58,14 +58,20 @@ def pytest_unconfigure(config):
     create_new_file(contents=sessionlog)
 
 
-def pytest_terminal_summary(terminal_reporter):
+def pytest_terminal_summary(terminalreporter):
+    """
+    Given a terminal reporter, call our custom writer callback to write to wandb
+
+    NOTE: The lack of snake case of `terminalreporter` is important here because it is
+    dynamically passed based on the name of the plugin - which is sans snake case.
+    """
     import _pytest.config  # noqa: 401
 
-    if "failed" in terminal_reporter.stats:
-        for rep in terminal_reporter.stats.get('failed'):
+    if "failed" in terminalreporter.stats:
+        for rep in terminalreporter.stats.get('failed'):
             file = StringIO()
 
-            terminal_writer = _pytest.config.create_terminal_writer(terminal_reporter.config, file)
+            terminal_writer = _pytest.config.create_terminal_writer(terminalreporter.config, file)
             rep.toterminal(terminal_writer)
 
             pytest_value = file.getvalue()
